==> librenms-23.9.1v0.tgz: librenms/app/Http/Controllers/Device/Tabs/HealthController.php <==
<?php
/**
 * HealthController.php
 *
 * -Description-
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * @link       https://www.librenms.org
 *
 * @copyright  2020 Tony Murray
 * @author     Tony Murray <murraytony@gmail.com>
 */

namespace App\Http\Controllers\Device\Tabs;

use App\Models\Device;
use LibreNMS\Interfaces\UI\DeviceTab;

class HealthController implements DeviceTab
{
    public function visible(Device $device): bool
    {
        return $device->storage()->exists() || $device->sensors()->exists() || $device->mempools()->exists() || $device->processors()->exists();
    }

    public function slug(): string
    {
        return 'health';
    }

    public function icon(): string
    {
        return 'fa-heartbeat';
    }

    public function name(): string
    {
        return __('Health');
    }

    public function data(Device $device): array
    {
        return [];
    }
}

==> librenms-24.8.1v0.tgz: librenms/app/Http/Controllers/Device/Tabs/HealthController.php <==
<?php
/**
 * HealthController.php
 *
 * -Description-
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * @link       https://www.librenms.org
 *
 * @copyright  2020 Tony Murray
 * @author     Tony Murray <murraytony@gmail.com>
 */

namespace App\Http\Controllers\Device\Tabs;

use App\Models\Device;
use Illuminate\Http\Request;
use LibreNMS\Interfaces\UI\DeviceTab;

class HealthController implements DeviceTab
{
    public function visible(Device $device): bool
    {
        return $device->storage()->exists() || $device->sensors()->exists() || $device->mempools()->exists() || $device->processors()->exists();
    }

    public function slug(): string
    {
        return 'health';
    }

    public function icon(): string
    {
        return 'fa-heartbeat';
    }

    public function name(): string
    {
        return __('Health');
    }

    public function data(Device $device, Request $request): array
    {
        return [];
    }
}
